@@ -2,7 +2,7 @@
 #'
 #' \code{stat_wb_total} computes means under a curve. It first integrates the
 #'   area under a spectral curve and also the mean expressed per nanaometre of
-#'   wavelength for each waveband in the input. Sets suitable default aestheics
+#'   wavelength for each waveband in the input. Sets suitable default aesthetics
 #'   for "rect", "hline", "vline", "text" and "label" geoms displaying "totals"
 #'   per waveband.
 #'
@@ -39,17 +39,47 @@
 #' @param ypos.fixed numeric If not \code{NULL} used a constant value returned
 #'   in \code{y}.
 #'
+#' @return A data frame with one row for each waveband object in the argument
+#' to \code{w.band}. Wavebeand outside the range of the spectral data are
+#' trimmed or discarded.
+#'
 #' @section Computed variables:
+#' What it is named integral below is the result of appying \code{integral.fun},
+#' with default \code{integrate_xy}.
 #' \describe{
-#'   \item{label}{intergral value as formatted text}
+#'   \item{y.label}{ymean multiplied by \code{label.mult} and formatted
+#'   according to \code{label.fmt}}
 #'   \item{x}{w.band-midpoint}
 #'   \item{xmin}{w.band minimum}
 #'   \item{xmax}{w.band maximum}
-#'   \item{ymean}{Mean value as numeric}
-#'   \item{yint}{Integral value as numeric}
+#'   \item{ymin}{data$y minimum}
+#'   \item{ymax}{data$y maximum}
+#'   \item{yint}{data$y integral for the range of \code{w.band}}
+#'   \item{xmean}{yint divided by spread(w.band)}
+#'   \item{y}{ypos.fixed or top of data, adjusted by \code{ypos.mult}}
+#'   \item{wb.color}{color of the w.band}
+#'   \item{wb.name}{label of w.band}
 #' }
 #'
-#' @import photobiology
+#' @section Default aesthetics:
+#' Set by the statistic and available to geoms.
+#' \describe{
+#'   \item{label}{..y.label..}
+#'   \item{x}{..x..}
+#'   \item{xmin}{..xmin..}
+#'   \item{xmax}{..xmax..}
+#'   \item{ymin}{..y.. - (..ymax.. - ..ymin..) * 0.03}
+#'   \item{ymax}{..y.. + (..ymax.. - ..ymin..) * 0.03}
+#'   \item{yintercept}{..ymean..}
+#'   \item{fill}{..wb.color..}
+#' }
+#'
+#' @section Required aesthetics:
+#' Required by the statistic and need to be set with \code{aes()}.
+#' \describe{
+#'   \item{x}{numeric, wavelength in nanometres}
+#'   \item{y}{numeric, a spectral quantity}
+#' }
 #'
 #' @examples
 #' library(photobiology)
@@ -67,7 +97,7 @@
 #'
 stat_wb_total <- function(mapping = NULL, data = NULL, geom = "rect",
                        w.band = NULL,
-                       integral.fun = photobiology::integrate_xy,
+                       integral.fun = integrate_xy,
                        label.mult = 1,
                        label.fmt = "%.3g",
                        ypos.mult = 1.07,
@@ -102,7 +132,7 @@ StatWbTotal <-
                                             label.fmt,
                                             ypos.mult,
                                             ypos.fixed) {
-                     if (is.null(w.band)) {
+                     if (length(w.band) == 0) {
                        w.band <- waveband(data$x)
                      }
                      if (is.any_spct(w.band) ||
